TooltipAlignment enum

The alignment of the tooltip along the cross-axis of the direction.

For TooltipDirection.top and TooltipDirection.bottom:

  • start aligns to the left (or right in RTL).
  • center aligns to the horizontal center.
  • end aligns to the right (or left in RTL).

For TooltipDirection.left and TooltipDirection.right:

  • start aligns to the top.
  • center aligns to the vertical center.
  • end aligns to the bottom.
Inheritance
Available extensions

Values

start → const TooltipAlignment

Aligns the tooltip to the start edge of the child.

center → const TooltipAlignment

Aligns the tooltip to the center of the child.

end → const TooltipAlignment

Aligns the tooltip to the end edge of the child.

startTargetCenter → const TooltipAlignment

Aligns the tooltip like start, but the arrow points to the center of the target widget instead of using the fixed arrowPositionRatio.

endTargetCenter → const TooltipAlignment

Aligns the tooltip like end, but the arrow points to the center of the target widget instead of using the fixed arrowPositionRatio.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<TooltipAlignment>
A constant List of the values in this enum, in order of their declaration.