FlattenResult<T> class

The result of a Flattener.update: the current flat list plus, when the update was an incremental single-node change, its FlattenChange.

Constructors

FlattenResult({required List<FlatNode<T>> list, required FlattenChange? change})
const

Properties

change FlattenChange?
Non-null only for an incremental single-node expand/collapse; null for a full rebuild or a cache hit.
final
hashCode int
The hash code for this object.
no setterinherited
list List<FlatNode<T>>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited