change property
Non-null only for an incremental single-node expand/collapse; null for a full rebuild or a cache hit.
Implementation
final FlattenChange? change;
Non-null only for an incremental single-node expand/collapse; null for a full rebuild or a cache hit.
final FlattenChange? change;