services/view_mode_projection library

Classes

ViewModeProjection
Projects the input hierarchy onto the list of root nodes visible in a given ViewMode — the code counterpart of the View Mode projection described in CONTEXT.md.