ExpandableNodeRenderer<T> class
Renders an expandable-container row (Folder or Parent). Consumes an ExpandableNodeThemeView so one renderer serves both tiers without switching on type. Never handles Selection (ADR-0003).
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- ExpandableNodeRenderer
Constructors
-
ExpandableNodeRenderer({Key? key, required FlatNode<
T> flatNode, required RowMetrics<T> metrics, required ExpandableNodeThemeView<T> themeView, required bool useOpenState, required bool isExpanded, required dynamic onTap(Node<T> )?, required double scale}) -
const
Properties
-
flatNode
→ FlatNode<
T> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isExpanded → bool
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
-
metrics
→ RowMetrics<
T> -
final
-
onTap
→ dynamic Function(Node<
T> )? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scale → double
-
final
-
themeView
→ ExpandableNodeThemeView<
T> -
final
- useOpenState → bool
-
Whether this tier uses expanded/collapsed icons. Folders always do;
Parents only do in tree View Mode.
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited