FolderView<T> class

Inheritance

Constructors

FolderView({Key? key, required List<Node<T>> data, required ViewMode mode, dynamic onNodeTap(Node<T>)?, dynamic onDoubleNodeTap(Node<T>)?, dynamic onSecondaryNodeTap(Node<T>, TapDownDetails)?, Set<String>? selectedNodeIds, Set<String>? expandedNodeIds, FlutterFolderViewTheme<T>? theme, double scale = 1.0, ValueChanged<double>? onScaleChanged, double scaleStep = 0.05, bool? blockModifierScroll})
const

Properties

blockModifierScroll bool?
Whether to block normal scrolling while Ctrl (Windows/Linux) or Cmd (macOS) is held, so that those scroll events can be used for zoom/scale instead.
final
data List<Node<T>>
final
expandedNodeIds Set<String>?
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
mode ViewMode
final
onDoubleNodeTap → dynamic Function(Node<T>)?
final
onNodeTap → dynamic Function(Node<T>)?
final
onScaleChanged ValueChanged<double>?
Callback fired when the user Ctrl+scrolls (or Cmd+scrolls on macOS) over the view, requesting a scale change.
final
onSecondaryNodeTap → dynamic Function(Node<T>, TapDownDetails)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scale double
Scale factor for the content (default 1.0).
final
scaleStep double
The amount scale changes per mouse wheel tick when onScaleChanged is active. Defaults to 0.05.
final
selectedNodeIds Set<String>?
final
theme FlutterFolderViewTheme<T>?
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<FolderView<T>>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited