blockCtrlScroll property
When true, normal scrolling is blocked while Ctrl (Windows/Linux) or
Cmd (macOS) is held, so that those scroll events can be used for
zoom/scale instead.
Implementation
final bool blockCtrlScroll;
When true, normal scrolling is blocked while Ctrl (Windows/Linux) or
Cmd (macOS) is held, so that those scroll events can be used for
zoom/scale instead.
final bool blockCtrlScroll;