scale property
Scale factor for the content (default 1.0).
Scales all layout dimensions (row height, icon sizes, text size, spacing, line width, indentation) proportionally. Scrollbars are NOT scaled.
Implementation
final double scale;
Scale factor for the content (default 1.0).
Scales all layout dimensions (row height, icon sizes, text size, spacing, line width, indentation) proportionally. Scrollbars are NOT scaled.
final double scale;