change property
Incremental single-node change from the Flattener, or null for a full rebuild / no change. Drives the scroll anchor.
Implementation
final FlattenChange? change;
Incremental single-node change from the Flattener, or null for a full rebuild / no change. Drives the scroll anchor.
final FlattenChange? change;