connectorX property
Absolute x-centre of this row's own connector, or null for a root row (a root has no parent to connect to).
Implementation
final double? connectorX;
Absolute x-centre of this row's own connector, or null for a root row (a root has no parent to connect to).
final double? connectorX;